# Feature Store Tools


**Dependencies**

Assumes Teradata >=17.20.

**fs** tools:

- reconect_to_database - reestablishes a connection the the Teradata database
- fs_setFeatureStoreConfig - sets the feature store config for the session
- fs_getFeatureStoreConfig - gets the feature store config for the session
- fs_isFeatureStorePresent - confirms that a feature store has been created
- fs_featureStoreContent - returns a summary of the feature store
- fs_getDataDomains - lists the available domains in a feature store
- fs_getFeatures - gets the features within the feature store
- fs_getAvailableDatasets - lists the available datasets in the feature store
- fs_getFeatureDataModel - returns the schema of the feature store
- fs_getAvailableEntities - returns the entities in a domain
- fs_createDataset - creates a data set from the feature store


**fs** prompts:



[Return to Main README](../../../../README.md)
